pub struct CloneString<V: AsRef<str>>(pub V);Expand description
A string type which is cloned to String to use as an attribute value.
This wrapepr type exists to draw attention to the fact that using a borrowed
string value requires cloning to a persistent string in the attribute state.
This also permits a more efficient implementation of &'static str, which
does not need this wrapper.
Tuple Fields
0: VTrait Implementations
Sourceimpl<V: Clone + AsRef<str>> Clone for CloneString<V>
impl<V: Clone + AsRef<str>> Clone for CloneString<V>
Sourcefn clone(&self) -> CloneString<V>
fn clone(&self) -> CloneString<V>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<V: Copy + AsRef<str>> Copy for CloneString<V>
impl<V: Eq + AsRef<str>> Eq for CloneString<V>
impl<V: PartialEq + AsRef<str>> StructuralPartialEq for CloneString<V>